@@ -6,6 +6,7 @@ import (
 	"os"
 
 	"github.com/armosec/kubescape/cautils"
+	"github.com/armosec/kubescape/cautils/logger"
 	"github.com/armosec/kubescape/resultshandling/printer"
 	"github.com/armosec/opa-utils/reporthandling"
 )
@@ -31,13 +32,11 @@ func (junitPrinter *JunitPrinter) ActionPrint(opaSessionObj *cautils.OPASessionO
 
 	junitResult, err := convertPostureReportToJunitResult(opaSessionObj.PostureReport)
 	if err != nil {
-		fmt.Println("Failed to convert posture report object!")
-		os.Exit(1)
+		logger.L().Fatal("failed to convert posture report object")
 	}
 	postureReportStr, err := xml.Marshal(junitResult)
 	if err != nil {
-		fmt.Println("Failed to convert posture report object!")
-		os.Exit(1)
+		logger.L().Fatal("failed to convert posture report object")
 	}
 	junitPrinter.writer.Write(postureReportStr)
 }
@@ -123,4 +122,4 @@ func convertPostureReportToJunitResult(postureResult *reporthandling.PostureRepo
 		juResult.Suites = append(juResult.Suites, suite)
 	}
 	return &juResult, nil
-}
\ No newline at end of file
+}
