@@ -1,9 +1,8 @@
 package resultshandling
 
 import (
-	"fmt"
-
 	"github.com/armosec/kubescape/cautils"
+	"github.com/armosec/kubescape/cautils/logger"
 	"github.com/armosec/kubescape/resultshandling/printer"
 	"github.com/armosec/kubescape/resultshandling/reporter"
 	"github.com/armosec/opa-utils/reporthandling"
@@ -30,7 +29,7 @@ func (resultsHandler *ResultsHandler) HandleResults(scanInfo *cautils.ScanInfo)
 	resultsHandler.printerObj.ActionPrint(opaSessionObj)
 
 	if err := resultsHandler.reporterObj.ActionSendReport(opaSessionObj); err != nil {
-		fmt.Println(err)
+		logger.L().Error(err.Error())
 	}
 
 	score := opaSessionObj.Report.SummaryDetails.Score
